# Tool Documentation

Documentation for individual MCP tools provided by MCP Vector Search.

## Contents

- [save_report Tool](./save_report.md) — Reference for the `save_report` MCP tool used to persist analysis reports to disk

## Related Documentation

- [Parent Index](../README.md)
- [Reference Documentation](../reference/README.md)
- [User Guides](../guides/README.md)
